# tkt-Toolkit
****
## Version : 1.7.5
This Package is made and published by the Suprime LLC

Read more about the License in the ``license.txt`` file.
# Used packages:
****
* **base64**
* **json**
* **requests**
* **socket**
* **googletrans**
* **piexif**  
* **speech_recognition**
* **cryptography**
* **gtts**
* **random**
* **string**
* **TikTokApi**
# Description:
****
**Suprime's tkt-Toolkit python package, is a wide collection of packages and scripts, bundled in to
one package. It is optimized for python 3.8, but it also works with python 3.9,3.7,3.6.
Not all of the scripts used are made by us.**
# Features:
****
* **Voice recognition using pyaudio and speech_recognition.**
####  
* **Translation using googletrans.**
####
* **Cryptography using cryptography and xor.**
####
* **Tracking features using mediapipe and opencv**
####  
* **Smaller features: Weather-data, TextToSpeech, Get-ip, Calculator**
* ### There are features still in progress
# Contact:
****
**Our email support: suprime.sendings@gmail.com**
